runtimepath

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// EnvHome overrides the local sshx runtime directory. It is primarily useful
	// for isolated agent and CI runs that must not touch a user's real config.
	EnvHome = "SSHX_HOME"
	// DefaultDir is the directory used below the current user's home directory.
	DefaultDir = ".sshx"
)

Variables

This section is empty.

Functions

func Observations

func Observations() (string, error)

Observations returns the optional local observation mirror directory.

func Plugins

func Plugins() (string, error)

Plugins returns the directory that owns locally installed and editable inspection plugins.

func Root

func Root() (string, error)

Root returns the absolute local sshx runtime directory.

Types

This section is empty.

Jump to